==> org.eclipse.papyrus.infra.ui.source_1.3.0.201703080851.jar: org/eclipse/papyrus/infra/ui/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2013 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Vincent Lorenzo (CEA LIST) vincent.lorenzo@cea.fr - Initial API and implementation
 *
 *****************************************************************************/
package org.eclipse.papyrus.infra.ui.messages;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.papyrus.infra.ui.messages.messages"; //$NON-NLS-1$

	public static String AbstractPreferenceKeyDialog_Level;

	public static String AbstractPreferenceKeyDialog_Localization;

	public static String AbstractPreferenceKeyDialog_Pref_Kind;

	public static String AbstractPreferenceKeyDialog_WouldYouLikeOverloadPreferences;

	public static String AbstractStringValueConverter_NoXReprensentedByYHaveBeenFound;

	public static String AbstractStringValueConverter_SomeStringsAreNotValidToCreateY;

	public static String AbstractStringValueConverter_SomeStringsCantBeResolvedToFindY;

	public static String AbstractStringValueConverter_TheFeatureXCantBeResolved;

	public static String AbstractStringValueConverter_TheStringValueXCantBeResolved;

	public static String AbstractStringValueConverter_TheStringXIsNotValidToCreateY;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.papyrus.infra.ui.source_2.0.0.201706140736.jar: org/eclipse/papyrus/infra/ui/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2013 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Vincent Lorenzo (CEA LIST) vincent.lorenzo@cea.fr - Initial API and implementation
 *
 *****************************************************************************/
package org.eclipse.papyrus.infra.ui.messages;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.papyrus.infra.ui.messages.messages"; //$NON-NLS-1$

	public static String AbstractPreferenceKeyDialog_Level;

	public static String AbstractPreferenceKeyDialog_Localization;

	public static String AbstractPreferenceKeyDialog_Pref_Kind;

	public static String AbstractPreferenceKeyDialog_WouldYouLikeOverloadPreferences;

	public static String AbstractStringValueConverter_NoXReprensentedByYHaveBeenFound;

	public static String AbstractStringValueConverter_SomeStringsAreNotValidToCreateY;

	public static String AbstractStringValueConverter_SomeStringsCantBeResolvedToFindY;

	public static String AbstractStringValueConverter_TheFeatureXCantBeResolved;

	public static String AbstractStringValueConverter_TheStringValueXCantBeResolved;

	public static String AbstractStringValueConverter_TheStringXIsNotValidToCreateY;

	public static String RichtextPreferencePage_Description;

	public static String RichtextPreferencePage_FirstBooleanEditorName;

	public static String RichtextPreferencePage_SecondBooleanEditorName;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
